{% extends DYFORM_BASE_TEMPLATE %}
{% load static %}
{% load dynaform %}
{% block content %}
<div class="dynaform-form">
    <table class="table">
        <thead>
            <tr>
                {% for column in columns %}
                <th scope="col">{{ column }}</th>
                {% endfor %}
                <th>Action</th>
            </tr>
        </thead>
        <tbody>{% for row in rows %}
            <tr>
                {% for column in columns %}
                <th>{{ row.data|get_item:column }}</th>
                {% endfor %}
                <th>
                    {% link_to_dynaform_data_edit row "btn btn-primary" %}
                    <form method="delete">
                        {% link_to_dynaform_data_delete row "btn btn-danger" %}
                    </form>
                </th>
            </tr>{% endfor %}
        </tbody>
    </table>
</div>
{% endblock %}