<!DOCTYPE html>
<html>

<head>
  <title>Django DynaForm</title>
  <meta name="author" content="Loghman Barari">
  <meta name="description" content="Dynamic Django Form">
  <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.0.2/dist/css/bootstrap.min.css" rel="stylesheet"
    integrity="sha384-EVSTQN3/azprG1Anm3QDgpJLIm9Nao0Yz1ztcQTwFspd3yD65VohhpuuCOmLASjC" crossorigin="anonymous">
  <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.3.0/font/bootstrap-icons.css">
  <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.0.2/dist/js/bootstrap.bundle.min.js"
    integrity="sha384-MrcW6ZMFYlzcLA8Nl+NtUVF0sA7MsXsP1UyJoMp4YLEuNSfAP+JcXn/tWtIaxVXM"
    crossorigin="anonymous"></script>
  <style>
    .dynaform-body {
      padding: 1.5rem;
      margin-right: 0;
      margin-left: 0;
      border-width: 1px;
      border-top-left-radius: .25rem;
      border-top-right-radius: .25rem;
    }

    .dynaform-form {
      padding: 1.5rem;
      margin-right: 0;
      margin-left: 0;
      border-width: 1px;
      border-top-left-radius: 0.25rem;
      border-top-right-radius: 0.25rem;
      position: relative;
      border: solid #dee2e6;
    }
  </style>
</head>

<body>
  <div class="dynaform-body">
    {% block content %}
    {% endblock content %}
  </div>
</body>

</html>